@@ -12,12 +12,9 @@ class PNGExport(Action):
         self.sensitive = tab and True or False
 
     def execute(self):
-        if gtk.gtk_version < (2, 4, 0):
-            filesel = gtk.FileSelection('Export diagram to PNG file')
-        else:
-            filesel = gtk.FileChooserDialog(title='Export diagram to PNG file',
-                                            action=gtk.FILE_CHOOSER_ACTION_SAVE,
-                                            buttons=(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_SAVE,gtk.RESPONSE_OK))
+        filesel = gtk.FileChooserDialog(title='Export diagram to PNG file',
+                                        action=gtk.FILE_CHOOSER_ACTION_SAVE,
+                                        buttons=(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_SAVE,gtk.RESPONSE_OK))
         filesel.set_filename((self.get_window().get_current_diagram().name or 'export') + '.png')
 
         response = filesel.run()
