@@ -7,7 +7,7 @@ __date__ = '$date$'
 
 import gobject
 import diacanvas
-import gaphor.misc.uniqueid as uniqueid
+from gaphor.misc import uniqueid
 
 # Map UML elements to their (default) representation.
 _uml_to_item_map = { }
@@ -69,10 +69,15 @@ from generalization import GeneralizationItem
 from implementation import ImplementationItem
 from association import AssociationItem
 from extension import ExtensionItem
-from node import InitialNodeItem, ActivityFinalNodeItem, DecisionNodeItem
+from activitynodes import InitialNodeItem, ActivityFinalNodeItem, DecisionNodeItem
 from action import ActionItem
 from flow import FlowItem
 from component import ComponentItem
+from artifact import ArtifactItem
+from node import NodeItem
+from interaction import InteractionItem
+from lifeline import LifelineItem
+from message import MessageItem
 import itemactions
 
 #if __debug__: 
