@@ -9,19 +9,18 @@
 
 from __future__ import generators
 
+from math import atan, pi, sin, cos
+
 import gobject
 import pango
 import diacanvas
 import diacanvas.shape
 import diacanvas.geometry
-import gaphor
-import gaphor.UML as UML
+
+from gaphor import resource, UML
 from gaphor.diagram import initialize_item
-
-from diagramitem import DiagramItem
-from relationship import RelationshipItem
-
-from math import atan, pi, sin, cos
+from gaphor.diagram.diagramitem import DiagramItem
+from gaphor.diagram.relationship import RelationshipItem
 
 class AssociationItem(RelationshipItem, diacanvas.CanvasGroupable, diacanvas.CanvasEditable):
     """AssociationItem represents associations. 
@@ -93,6 +92,19 @@ class AssociationItem(RelationshipItem, diacanvas.CanvasGroupable, diacanvas.Can
         self._dir.set_fill(diacanvas.shape.FILL_SOLID)
         self._dir.set_cyclic(True)
 
+        self._head_xa = diacanvas.shape.Path()
+        self._head_xa.set_line_width(2.0)
+
+        self._head_xb = diacanvas.shape.Path()
+        self._head_xb.set_line_width(2.0)
+
+        self._tail_xa = diacanvas.shape.Path()
+        self._tail_xa.set_line_width(2.0)
+
+        self._tail_xb = diacanvas.shape.Path()
+        self._tail_xb.set_line_width(2.0)
+
+
     def save(self, save_func):
         RelationshipItem.save(self, save_func)
         self.save_property(save_func, 'show-direction')
@@ -147,6 +159,11 @@ class AssociationItem(RelationshipItem, diacanvas.CanvasGroupable, diacanvas.Can
 
     tail_end = property(lambda self: self._tail_end)
 
+    def unlink(self):
+        self._head_end.unlink()
+        self._tail_end.unlink()
+        RelationshipItem.unlink(self)
+
     def get_popup_menu(self):
         if self.subject:
             return self.popup_menu + self.association_popup_menu
@@ -197,6 +214,7 @@ class AssociationItem(RelationshipItem, diacanvas.CanvasGroupable, diacanvas.Can
         #return x, y, max(x + 10, x + w), max(y + 10, y + h)
         return x, y, x + w, y + h
 
+
     def update_dir(self, p1, p2):
         """Create a small arrow near the middle of the association line and
         let it point in the direction of self.subject.memberEnd[0].
@@ -238,6 +256,9 @@ class AssociationItem(RelationshipItem, diacanvas.CanvasGroupable, diacanvas.Can
 
     def on_update(self, affine):
         """Update the shapes and sub-items of the association."""
+
+        handles = self.handles
+
         # Update line endings:
         head_subject = self._head_end.subject
         tail_subject = self._tail_end.subject
@@ -250,11 +271,13 @@ class AssociationItem(RelationshipItem, diacanvas.CanvasGroupable, diacanvas.Can
             elif tail_subject.aggregation == intern('shared'):
                 self.set(has_head=1, head_a=20, head_b=10, head_c=6, head_d=6,
                          head_fill_color=diacanvas.color(255,255,255,255))
-            elif head_subject.class_:
+            elif self._head_end.get_navigability():
                 # This side is navigable:
                 self.set(has_head=1, head_a=0, head_b=15, head_c=6, head_d=6)
             else:
                 self.set(has_head=0)
+                if self._head_end.get_navigability() == False:
+                    xs(self, handles[0].get_pos_i(), handles[1].get_pos_i(), 'head')
 
             if head_subject.aggregation == intern('composite'):
                 self.set(has_tail=1, tail_a=20, tail_b=10, tail_c=6, tail_d=6,
@@ -262,15 +285,17 @@ class AssociationItem(RelationshipItem, diacanvas.CanvasGroupable, diacanvas.Can
             elif head_subject.aggregation == intern('shared'):
                 self.set(has_tail=1, tail_a=20, tail_b=10, tail_c=6, tail_d=6,
                          tail_fill_color=diacanvas.color(255,255,255,255))
-            elif tail_subject.class_:
+            elif self._tail_end.get_navigability():
                 # This side is navigable:
                 self.set(has_tail=1, tail_a=0, tail_b=15, tail_c=6, tail_d=6)
             else:
                 self.set(has_tail=0)
+                if self._tail_end.get_navigability() == False:
+                    xs(self, handles[-1].get_pos_i(), handles[-2].get_pos_i(), 'tail')
 
+        # update relationship after self.set calls to avoid circural updates
         RelationshipItem.on_update(self, affine)
 
-        handles = self.handles
         # Calculate alignment of the head name and multiplicity
         self._head_end.update_labels(handles[0].get_pos_i(),
                                      handles[1].get_pos_i())
@@ -307,6 +332,17 @@ class AssociationItem(RelationshipItem, diacanvas.CanvasGroupable, diacanvas.Can
         if self._show_direction:
             yield self._dir
 
+        if self._head_end.subject and self._tail_end.subject:
+            if self._tail_end.subject.aggregation == intern('none') \
+                    and self._head_end.get_navigability() == False:
+                yield self._head_xa
+                yield self._head_xb
+
+            if self._head_end.subject.aggregation == intern('none') \
+                    and self._tail_end.get_navigability() == False:
+                yield self._tail_xa
+                yield self._tail_xb
+
     # Gaphor Connection Protocol
 
     def find_relationship(self, head_type, tail_type):
@@ -321,7 +357,7 @@ class AssociationItem(RelationshipItem, diacanvas.CanvasGroupable, diacanvas.Can
         # Find all associations and determine if the properties on the
         # association ends have a type that points to the class.
         Association = UML.Association
-        for assoc in gaphor.resource(UML.ElementFactory).itervalues():
+        for assoc in resource(UML.ElementFactory).itervalues():
             if isinstance(assoc, Association):
                 #print 'assoc.memberEnd', assoc.memberEnd
                 end1 = assoc.memberEnd[0]
@@ -372,7 +408,7 @@ class AssociationItem(RelationshipItem, diacanvas.CanvasGroupable, diacanvas.Can
             # Find all associations and determine if the properties on the
             # association ends have a type that points to the class.
             Association = UML.Association
-            for assoc in gaphor.resource(UML.ElementFactory).itervalues():
+            for assoc in resource(UML.ElementFactory).itervalues():
                 if isinstance(assoc, Association):
                     #print 'assoc.memberEnd', assoc.memberEnd
                     end1 = assoc.memberEnd[0]
@@ -397,7 +433,7 @@ class AssociationItem(RelationshipItem, diacanvas.CanvasGroupable, diacanvas.Can
             else:
                 # TODO: How should we handle other types than Class???
 
-                element_factory = gaphor.resource(UML.ElementFactory)
+                element_factory = resource(UML.ElementFactory)
                 relation = element_factory.create(UML.Association)
                 head_end = element_factory.create(UML.Property)
                 head_end.lowerValue = element_factory.create(UML.LiteralSpecification)
@@ -484,6 +520,8 @@ class AssociationEnd(diacanvas.CanvasItem, diacanvas.CanvasEditable, DiagramItem
     FONT='sans 10'
 
     head_popup_menu = (
+        'Head_unknownNavigation',
+        'Head_isNotNavigable',
         'Head_isNavigable',
         'separator',
         'Head_AggregationNone',
@@ -492,6 +530,8 @@ class AssociationEnd(diacanvas.CanvasItem, diacanvas.CanvasEditable, DiagramItem
     )
 
     tail_popup_menu = (
+        'Tail_unknownNavigation',
+        'Tail_isNotNavigable',
         'Tail_isNavigable',
         'separator',
         'Tail_AggregationNone',
@@ -558,39 +598,86 @@ class AssociationEnd(diacanvas.CanvasItem, diacanvas.CanvasEditable, DiagramItem
                 self._mult.set_text(m)
                 self.request_update()
 
+
+    def get_navigability(self):
+        """
+        Check navigability of the AssociationEnd. If property is owned by
+        class via ownedAttribute, then it is navigable. If property is
+        owned by association by owndedEnd, then it is not navigable.
+        Otherwise the navigability is unknown.
+
+        Returned navigability values:
+            - None  - unknown
+            - False - not navigable
+            - True  - navigable
+        """
+        navigability = None # unknown navigability as default
+        subject = self.subject
+
+        if subject and subject.opposite:
+            opposite = subject.opposite
+            if isinstance(opposite.type, UML.Interface):
+                type = subject.interface_
+            else: # isinstance(opposite.type, UML.Class):
+                type = subject.class_
+
+            if type and subject in type.ownedAttribute:
+                navigability = True
+            elif subject.association and subject in subject.association.ownedEnd:
+                navigability = False
+
+        return navigability
+                
+
     def set_navigable(self, navigable):
-        """Change the AsociationEnd's navigability.
+        """Change the AssociationEnd's navigability.
 
         A warning is issued if the subject or opposite property is missing.
         """
         subject = self.subject
         if subject and subject.opposite:
             opposite = subject.opposite
-            if navigable:
-                # Set owner to the class.
-                if subject.owningAssociation:
-                    del subject.owningAssociation
 
+            #
+            # Remove any navigability info, so unknown navigability state
+            # is the default.
+            #
+
+            # if navigable
+            if isinstance(opposite.type, UML.Class):
+                if subject.class_:
+                    del subject.class_
+            elif isinstance(opposite.type, UML.Interface):
+                if subject.interface_:
+                    del subject.interface_
+            else:
+                assert 0, 'Should never be reached'
+
+            # if not navigable
+            if subject.owningAssociation:
+                del subject.owningAssociation
+
+
+            #
+            # Set navigability.
+            #
+            if navigable:
                 if isinstance(opposite.type, UML.Class):
                     subject.class_ = opposite.type
                 elif isinstance(opposite.type, UML.Interface):
                     subject.interface_ = opposite.type
                 else:
                     assert 0, 'Should never be reached'
-            else:
-                if isinstance(opposite.type, UML.Class):
-                    if subject.class_:
-                        del subject.class_
-                elif isinstance(opposite.type, UML.Interface):
-                    if subject.interface_:
-                        del subject.interface_
-                else:
-                    assert 0, 'Should never be reached'
+            elif navigable == False:
                 subject.owningAssociation = subject.association
+
+            # else navigability is unknown
+
         else:
             log.warning('AssociationEnd.set_navigable: %s missing' % \
                         (subject and 'subject' or 'opposite Property'))
 
+
     def point_name(self, x, y):
         p = (x, y)
         drp = diacanvas.geometry.distance_rectangle_point
@@ -693,7 +780,8 @@ class AssociationEnd(diacanvas.CanvasItem, diacanvas.CanvasEditable, DiagramItem
         DiagramItem.on_subject_notify(self, pspec,
                         notifiers + ('aggregation', 'visibility',
                         'name', 'lowerValue.value',
-                        'upperValue.value', 'taggedValue.value'))
+                        'upperValue.value', 'taggedValue.value',
+                        'owningAssociation', 'class_', 'interface_'))
         #print 'w/ assoc', self.subject and self.subject.association
         self.set_text()
         self.request_update()
@@ -722,6 +810,15 @@ class AssociationEnd(diacanvas.CanvasItem, diacanvas.CanvasEditable, DiagramItem
         self.set_text()
         self.parent.request_update()
 
+    def on_subject_notify__owningAssociation(self, upper_value, pspec):
+        self.parent.request_update()
+
+    def on_subject_notify__class_(self, upper_value, pspec):
+        self.parent.request_update()
+
+    def on_subject_notify__interface_(self, upper_value, pspec):
+        self.parent.request_update()
+
     def on_update(self, affine):
         diacanvas.CanvasItem.on_update(self, affine)
 
@@ -785,5 +882,45 @@ class AssociationEnd(diacanvas.CanvasItem, diacanvas.CanvasEditable, DiagramItem
             #self.set_text()
             #log.info('editing done')
 
+
+def rotate(p1, p2, points):
+    """
+    Rotate points around p1. Rotation angle is determined by line (p0, p1).
+    Every point is moved into p1 + (10, 0) after rotation.
+    """
+    try:
+        angle = atan((p1[1] - p2[1]) / (p1[0] - p2[0]))
+    except ZeroDivisionError:
+        angle = pi * 1.5
+        
+
+    sin_angle = sin(angle)
+    cos_angle = cos(angle)
+
+    def r(a, b, x, y):
+        return (cos_angle * a - sin_angle * b + x,
+                sin_angle * a + cos_angle * b + y)
+
+    x0 = p1[0] < p2[0] and 10 or -10
+    y0 = 0
+
+    # rotate around the (10, 0)
+    x0, y0 = r(x0, y0, 0, 0)
+
+    # move to the destination point
+    x0 += p1[0]
+    y0 += p1[1]
+
+    return [ r(x, y, x0, y0) for x, y in points ]
+
+
+def xs(self, p0, p1, name):
+    """
+    Utility function to draw xs (unknown navigability).
+    """
+    points = rotate(p0, p1, ((-4, -4), (4, 4), (4, -4), (-4, 4)))
+    getattr(self, '_%s_xa' % name).line(points[0:2])
+    getattr(self, '_%s_xb' % name).line(points[2:])
+
 initialize_item(AssociationItem, UML.Association)
 initialize_item(AssociationEnd)
