@@ -3,13 +3,12 @@ Implementation - - - -|>
 '''
 # vim:sw=4
 
-import gaphor
-import gaphor.UML as UML
+from gaphor import resource
+from gaphor import UML
 from gaphor.diagram import initialize_item
-import gaphor.diagram.interface
-import relationship
+from gaphor.diagram.relationship import RelationshipItem
 
-class ImplementationItem(relationship.RelationshipItem):
+class ImplementationItem(RelationshipItem):
     default_look = {
         'dash': (7.0, 5.0),
         'has_head': 1,
@@ -25,7 +24,7 @@ class ImplementationItem(relationship.RelationshipItem):
     }
 
     def __init__(self, id = None):
-        relationship.RelationshipItem.__init__(self, id)
+        RelationshipItem.__init__(self, id)
         self.set(**self.default_look)
         
     # Gaphor Connection Protocol
@@ -71,7 +70,7 @@ class ImplementationItem(relationship.RelationshipItem):
             relation = self.find_relationship(s1, s2)
             if not relation:
                 #print 'No relationship found'
-                relation = gaphor.resource(UML.ElementFactory).create(UML.Implementation)
+                relation = resource(UML.ElementFactory).create(UML.Implementation)
                 relation.contract = s1
                 relation.implementatingClassifier = s2
             self.subject = relation
@@ -85,14 +84,15 @@ class ImplementationItem(relationship.RelationshipItem):
 
     def on_update(self, affine):
         # change look into solid line when connected to folded interface
+        from gaphor.diagram.interface import InterfaceItem
         conn_to = self.handles[0].connected_to
-        if isinstance(conn_to, gaphor.diagram.interface.InterfaceItem) \
+        if isinstance(conn_to, InterfaceItem) \
            and conn_to.is_folded():
             self.set(**self.folded_interface_look)
         else:
             self.set(**self.default_look)
 
-        relationship.RelationshipItem.on_update(self, affine)
+        RelationshipItem.on_update(self, affine)
 
 
 initialize_item(ImplementationItem, UML.Implementation)
