@@ -6,24 +6,27 @@ Commands related to the Diagram (DiaCanvas)
 from __future__ import generators
 
 import diacanvas
-import gaphor
-import gaphor.diagram
-import gaphor.UML as UML
+
+from gaphor import GaphorError, resource
+from gaphor import UML
 from gaphor.undomanager import UndoTransactionAspect, weave_method
 from gaphor.misc.action import Action, CheckAction, RadioAction, ObjectAction
 from gaphor.misc.action import register_action
 
-from klass import ClassItem
-from component import ComponentItem
-from attribute import AttributeItem
-from dependency import DependencyItem
-from operation import OperationItem
-from nameditem import NamedItem
-from interface import InterfaceItem
-from association import AssociationItem, AssociationEnd
+from gaphor.diagram.klass import ClassItem
+from gaphor.diagram.package import PackageItem
+from gaphor.diagram.component import ComponentItem
+from gaphor.diagram.attribute import AttributeItem
+from gaphor.diagram.dependency import DependencyItem
+from gaphor.diagram.operation import OperationItem
+from gaphor.diagram.nameditem import NamedItem
+from gaphor.diagram.interface import InterfaceItem
+from gaphor.diagram.association import AssociationItem, AssociationEnd
+from gaphor.diagram import ClassifierItem, ImplementationItem, \
+     GeneralizationItem, DependencyItem
 
 
-class NoFocusItemError(gaphor.GaphorError):
+class NoFocusItemError(GaphorError):
     pass
 
 
@@ -93,7 +96,7 @@ register_action(RenameItemAction, 'ItemFocus')
 
 class AbstractClassAction(CheckAction):
     id = 'AbstractClass'
-    label = 'Abstract class'
+    label = 'Abstract Class'
     tooltip='Abstract class'
 
     def init(self, window):
@@ -110,12 +113,42 @@ class AbstractClassAction(CheckAction):
 
     def execute(self):
         item = get_parent_focus_item(self._window)
-        item.subject.isAbstract = self.active
+        if item and item.subject:
+            item.subject.isAbstract = self.active
 
 weave_method(AbstractClassAction.execute, UndoTransactionAspect)
 register_action(AbstractClassAction, 'ItemFocus')
 
 
+class AbstractOperationAction(CheckAction):
+    id = 'AbstractOperation'
+    label = 'Abstract Operation'
+    tooltip='Abstract operation'
+
+    def init(self, window):
+        self._window = window
+
+    def update(self):
+        try:
+            get_parent_focus_item(self._window)
+            item = self._window.get_current_diagram_view() \
+                .focus_item.item
+        except NoFocusItemError:
+            pass
+        else:
+            if isinstance(item, OperationItem):
+                self.active = item.subject and item.subject.isAbstract
+
+    def execute(self):
+        item = self._window.get_current_diagram_view() \
+            .focus_item.item
+        if item and item.subject:
+            item.subject.isAbstract = self.active
+
+weave_method(AbstractOperationAction.execute, UndoTransactionAspect)
+register_action(AbstractOperationAction, 'ItemFocus')
+
+
 # NOTE: attributes and operations can now only be created on classes,
 #       actors and use-cases are also classifiers, but we can't add 
 #       attrs and opers via the UI right now.
@@ -142,7 +175,7 @@ class CreateAttributeAction(Action):
         focus_item = get_parent_focus_item(self._window)
         subject = focus_item.subject
         assert isinstance(subject, (UML.Class, UML.Interface))
-        elemfact = gaphor.resource(UML.ElementFactory)
+        elemfact = resource(UML.ElementFactory)
         
         attribute = elemfact.create(UML.Property)
         attribute.parse('new')
@@ -185,7 +218,7 @@ class CreateOperationAction(Action):
         focus_item = get_parent_focus_item(self._window)
         subject = focus_item.subject
         assert isinstance(subject, UML.Classifier)
-        elemfact = gaphor.resource(UML.ElementFactory)
+        elemfact = resource(UML.ElementFactory)
 
         operation = elemfact.create(UML.Operation)
         operation.parse('new()')
@@ -263,7 +296,7 @@ register_action(ShowAttributesAction, 'ItemFocus')
 class ShowOperationsAction(CheckAction):
     id = 'ShowOperations'
     label = 'Show Operations'
-    tooltip='show attribute compartment'
+    tooltip='Show attribute compartment'
 
     def init(self, window):
         self._window = window
@@ -274,7 +307,6 @@ class ShowOperationsAction(CheckAction):
         except NoFocusItemError:
             pass
         else:
-            from klass import ClassItem
             if isinstance(item, ClassItem):
                 self.active = item.get_property('show-operations')
 
@@ -372,7 +404,7 @@ register_action(OrthogonalAction, 'ItemFocus', 'AddSegment', 'DeleteSegment')
 
 class OrthogonalAlignmentAction(CheckAction):
     id = 'OrthogonalAlignment'
-    label = 'Switched alignment'
+    label = 'Switched Alignment'
     tooltip = 'Set the line to orthogonal'
 
     def init(self, window):
@@ -403,7 +435,7 @@ register_action(OrthogonalAlignmentAction, 'ItemFocus', 'Orthogonal')
 class AssociationShowDirectionAction(CheckAction):
     id = 'AssociationShowDirection'
     label = 'Show Direction'
-    tooltip='show direction arrow'
+    tooltip='Show direction arrow'
 
     def init(self, window):
         self._window = window
@@ -442,7 +474,7 @@ weave_method(AssociationInvertDirectionAction.execute, UndoTransactionAspect)
 register_action(AssociationInvertDirectionAction, 'ItemFocus')
 
 
-class NavigableAction(CheckAction):
+class NavigableAction(RadioAction):
     end_name=''
     def init(self, window):
         self._window = window
@@ -456,7 +488,7 @@ class NavigableAction(CheckAction):
             if isinstance(item, AssociationItem):
                 end = item.get_property(self.end_name)
                 if end.subject:
-                    self.active = (end.subject.classifier != None)
+                    self.active = (end.get_navigability() == self.navigable)
         except NoFocusItemError:
             pass
 
@@ -464,7 +496,7 @@ class NavigableAction(CheckAction):
         item = self.get_association_end()
         assert item.subject
         assert isinstance(item.subject, UML.Property)
-        item.set_navigable(self.active)
+        item.set_navigable(self.navigable)
 
 weave_method(NavigableAction.execute, UndoTransactionAspect)
 
@@ -473,18 +505,56 @@ class HeadNavigableAction(NavigableAction):
     id = 'Head_isNavigable'
     label = 'Navigable'
     end_name = 'head'
+    navigable = True
 
 register_action(HeadNavigableAction, 'ItemFocus')
 
 
+class HeadNotNavigableAction(NavigableAction):
+    id = 'Head_isNotNavigable'
+    label = 'Non-Navigable'
+    end_name = 'head'
+    navigable = False
+
+register_action(HeadNotNavigableAction, 'ItemFocus')
+
+
+class HeadUnknownNavigationAction(NavigableAction):
+    id = 'Head_unknownNavigation'
+    label = 'Unknown'
+    end_name = 'head'
+    navigable = None
+
+register_action(HeadUnknownNavigationAction, 'ItemFocus')
+
+
 class TailNavigableAction(NavigableAction):
     id = 'Tail_isNavigable'
     label = 'Navigable'
     end_name = 'tail'
+    navigable = True
 
 register_action(TailNavigableAction, 'ItemFocus')
 
 
+class TailNotNavigableAction(NavigableAction):
+    id = 'Tail_isNotNavigable'
+    label = 'Non-Navigable'
+    end_name = 'tail'
+    navigable = False
+
+register_action(TailNotNavigableAction, 'ItemFocus')
+
+
+class TailUnknownNavigationAction(NavigableAction):
+    id = 'Tail_unknownNavigation'
+    label = 'Unknown'
+    end_name = 'tail'
+    navigable = None
+
+register_action(TailUnknownNavigationAction, 'ItemFocus')
+
+
 class AggregationAction(RadioAction):
 
     def init(self, window):
@@ -710,7 +780,7 @@ register_action(AutoDependencyAction, 'ItemFocus')
 class IndirectlyInstantiatedComponentAction(CheckAction):
     id = 'IndirectlyInstantiated'
     label = 'Indirectly Instantiated'
-    tooltip = 'Indirectly Instantiated Component'
+    tooltip = 'Indirectly instantiated component'
 
     def init(self, window):
         self._window = window
@@ -781,7 +851,7 @@ weave_method(MoveAction.execute, UndoTransactionAspect)
 class MoveUpAction(MoveAction):
     id = 'MoveUp'
     label = 'Move Up'
-    tooltip = 'Move Up'
+    tooltip = 'Move up'
     move_action = 'moveUp' # name of method to move the element
 
     def _isSensitive(self, cls, item):
@@ -794,7 +864,7 @@ register_action(MoveUpAction, 'ItemFocus')
 class MoveDownAction(MoveAction):
     id = 'MoveDown'
     label = 'Move Down'
-    tooltip = 'Move Down'
+    tooltip = 'Move down'
     move_action = 'moveDown' # name of method to move the element
 
     def _isSensitive(self, cls, item):
@@ -865,7 +935,7 @@ class ApplyStereotypeAction(CheckAction, ObjectAction):
         except NoFocusItemError:
             pass
         else:
-            self.sensitive = isinstance(item, ClassItem)
+            self.sensitive = isinstance(item, (ClassItem, PackageItem))
             if self.sensitive and item.subject:
                 self.active = self.stereotype in item.subject.appliedStereotype
             else:
@@ -952,18 +1022,18 @@ class CreateLinksAction(Action):
         diagram = diagram_tab.get_diagram()
         for view_item in diagram_tab.get_view().selected_items:
             item = view_item.item
-            if isinstance(item, gaphor.diagram.ClassItem):
+            if isinstance(item, ClassItem):
                 self.create_missing_relationships(item, diagram,
-                                            gaphor.diagram.AssociationItem)
+                                                  AssociationItem)
 
-            if isinstance(item, gaphor.diagram.ClassifierItem):
+            if isinstance(item, ClassifierItem):
                 self.create_missing_relationships(item, diagram,
-                                            gaphor.diagram.ImplementationItem)
+                                                  ImplementationItem)
                 self.create_missing_relationships(item, diagram,
-                                            gaphor.diagram.GeneralizationItem)
+                                                  GeneralizationItem)
 
             self.create_missing_relationships(item, diagram,
-                                              gaphor.diagram.DependencyItem)
+                                              DependencyItem)
 
 weave_method(CreateLinksAction.execute, UndoTransactionAspect)
 register_action(CreateLinksAction, 'ItemFocus', 'ItemSelect')
