@@ -11,7 +11,7 @@ import gobject
 import pango
 import diacanvas
 
-import gaphor.UML as UML
+from gaphor import UML
 from gaphor.diagram import initialize_item
 from gaphor.i18n import _
 
@@ -161,7 +161,7 @@ class ClassItem(ClassifierItem, diacanvas.CanvasGroupable):
         Note: This method is also called from ExtensionItem.confirm_connect_handle
         """
         subject = self.subject
-        applied_stereotype = subject.appliedStereotype
+        #applied_stereotype = subject.appliedStereotype
         if not ClassifierItem.update_stereotype(self):
             if isinstance(subject, UML.Stereotype):
                 self.set_stereotype('stereotype')
@@ -226,7 +226,7 @@ class ClassItem(ClassifierItem, diacanvas.CanvasGroupable):
         """Remove a feature subitem.
         """
         if item in self._attributes:
-            print 'remove attr:', item
+            #print 'remove attr:', item
             self._attributes.remove(item)
             item.set_child_of(None)
         elif item in self._operations:
