@@ -13,19 +13,20 @@ class NamedItem(ElementItem, diacanvas.CanvasEditable):
         'name': (gobject.TYPE_STRING, 'name', '', '', gobject.PARAM_READWRITE)
     }
 
-    FONT='sans bold 10'
+    FONT = 'sans bold 10'
 
     popup_menu = (
         'RenameItem',
         'separator',
         'EditDelete',
+        'ShowElementInTreeView'
     )
 
     def __init__(self, id=None):
         ElementItem.__init__(self, id)
 
         self._name = diacanvas.shape.Text()
-        self._name.set_font_description(pango.FontDescription(NamedItem.FONT))
+        self._name.set_font_description(pango.FontDescription(self.FONT))
         self._name.set_alignment(pango.ALIGN_CENTER)
         #self._name.set_wrap_mode(diacanvas.shape.WRAP_NONE)
         self._name.set_markup(False)
@@ -79,8 +80,8 @@ class NamedItem(ElementItem, diacanvas.CanvasEditable):
 
     # CanvasItem callbacks:
 
-    def on_update(self, affine):
-        ElementItem.on_update(self, affine)
+    #def on_update(self, affine):
+    #    ElementItem.on_update(self, affine)
 
     def on_event (self, event):
         if event.type == diacanvas.EVENT_2BUTTON_PRESS:
