@@ -8,7 +8,7 @@ from __future__ import generators
 import gobject
 import pango
 import diacanvas
-import gaphor.UML as UML
+from gaphor import UML
 from gaphor.diagram import initialize_item
 from nameditem import NamedItem
 
