@@ -19,11 +19,13 @@ import types
 import sys
 import os.path
 import gc
-import UML
-import parser
-import diagram
+
 import diacanvas
-import gaphor
+
+from gaphor import UML
+from gaphor import parser
+from gaphor import diagram
+from gaphor import resource
 from gaphor.i18n import _
 #from gaphor.misc.xmlwriter import XMLWriter
 
@@ -123,11 +125,11 @@ def save_generator(writer=None, factory=None):
             save_value(name, value)
 
     if not factory:
-        factory = gaphor.resource(UML.ElementFactory)
+        factory = resource(UML.ElementFactory)
 
     writer.startDocument()
     writer.startElement('gaphor', { 'version': FILE_FORMAT_VERSION,
-                                    'gaphor-version': gaphor.resource('Version') })
+                                    'gaphor-version': resource('Version') })
 
     size = factory.size()
     n = 0
@@ -240,6 +242,7 @@ def load_elements_generator(elements, factory, gaphor_version=None):
 
     # Fix version inconsistencies
     version_0_5_2(elements, factory, gaphor_version)
+    version_0_7_1(elements, factory, gaphor_version)
 
     # do a postload:
     for id, elem in elements.items():
@@ -285,7 +288,7 @@ def load_generator(filename, factory=None):
 
     try:
         if not factory:
-            factory = gaphor.resource(UML.ElementFactory)
+            factory = resource(UML.ElementFactory)
         factory.flush()
         gc.collect()
         for percentage in load_elements_generator(elements, factory, gaphor_version):
@@ -301,7 +304,40 @@ def load_generator(filename, factory=None):
         raise
 
 
-# Version inconsistencies can be fixed:
+def version_0_7_1(elements, factory, gaphor_version):
+    """Before version 0.7.1, there were two states for association
+    navigability (in terms of UML 2.0): unknown and navigable.
+    In case of unknown navigability Property.owningAssociation was set.
+
+    Now, we have three states: unknown, non-navigable and navigable.
+    In case of unknown navigability the Property.owningAssociation
+    should not be set.
+    """
+    def fix(end1, end2):
+        if isinstance(end2.type, UML.Interface):
+            type = end1.interface_
+        else: # isinstance(end2.type, UML.Class):
+            type = end1.class_
+
+        # if the end of association is not navigable (in terms of UML 1.x)
+        # then set navigability to unknown (in terms of UML 2.0)
+        if not (type and end1 in type.ownedAttribute):
+            del end1.owningAssociation
+
+    if tuple(map(int, gaphor_version.split('.'))) < (0, 7, 1):
+        log.info('Fix navigability of Associations (file version: %s)' % gaphor_version)
+        for elem in elements.values():
+            try:
+                if elem.type == 'Association':
+                    asc = elem.element
+                    end1 = asc.memberEnd[0]
+                    end2 = asc.memberEnd[1]
+                    if end1 and end2:
+                        fix(end1, end2)
+                        fix(end2, end1)
+            except Exception, e:
+                log.error('Error while updating Association', e)
+
 
 def version_0_6_2(elements, factory, gaphor_version):
     """Before 0.6.2 an Interface could be represented by a ClassItem and
