@@ -5,8 +5,9 @@ Commands related to the Diagram (DiaCanvas)
 
 import gtk
 import diacanvas
-import gaphor
-import gaphor.UML as UML
+
+from gaphor import resource
+from gaphor import UML
 from gaphor.undomanager import UndoTransactionAspect, weave_method
 from gaphor.misc.action import Action, CheckAction, RadioAction
 from gaphor.misc.action import register_action as _register_action
@@ -141,7 +142,7 @@ register_action(DiagramDropAction)
 
 class SelectAllAction(Action):
     id = 'EditSelectAll'
-    label = '_Select all'
+    label = '_Select All'
     accel = 'C-a'
 
     def init(self, window):
@@ -159,7 +160,7 @@ register_action(SelectAllAction)
 
 class DeselectAllAction(Action):
     id = 'EditDeselectAll'
-    label = 'Des_elect all'
+    label = 'Des_elect All'
     accel = 'C-S-a'
 
     def init(self, window):
@@ -275,10 +276,10 @@ class CopyAction(Action):
                 copy_items.append(i.item)
                 #i.item.save(save_func)
             if copy_items:
-                gaphor.resource.set('copy-buffer', copy_items)
+                resource.set('copy-buffer', copy_items)
         tab = self._window.get_current_diagram_tab()
 
-register_action(CopyAction, 'ItemFocus')
+register_action(CopyAction, 'ItemFocus', 'ItemSelect', 'ItemSelectAll', 'EditDelete')
 
 
 class PasteAction(Action):
@@ -305,7 +306,7 @@ class PasteAction(Action):
 
     def update(self):
         diagram_tab = self._window.get_current_diagram_tab()
-        self.sensitive = diagram_tab and gaphor.resource('copy-buffer', [])
+        self.sensitive = diagram_tab and resource('copy-buffer', [])
 
     def _load_element(self, name, value):
         """Copy an element, preferbly from the list of new items,
@@ -323,7 +324,7 @@ class PasteAction(Action):
     def copy_func(self, name, value, reference=False):
         if reference or isinstance(value, UML.Element):
             self._load_element(name, value)
-        elif isinstance(value, gaphor.UML.collection):
+        elif isinstance(value, UML.collection):
             for item in value:
                 self._load_element(name, item)
         elif isinstance(value, diacanvas.CanvasItem):
@@ -334,19 +335,20 @@ class PasteAction(Action):
 
     def execute(self):
         view = self._window.get_current_diagram_view()
+        diagram = self._window.get_current_diagram()
         if not view:
             return
 
-        diagram = view.get_diagram()
+        #diagram = view.get_diagram()
         canvas = diagram.canvas
         if not canvas:
             return
 
-        copy_items = [ c for c in gaphor.resource('copy-buffer', []) if c.canvas ]
+        copy_items = [ c for c in resource('copy-buffer', []) if c.canvas ]
 
         # Mapping original id -> new item
         self._new_items = {}
-        self._factory = gaphor.resource('ElementFactory')
+        self._factory = resource(UML.ElementFactory)
 
         # Create new id's that have to be used to create the items:
         for ci in copy_items:
@@ -436,7 +438,7 @@ register_action(Zoom100Action)
 
 class SnapToGridAction(CheckAction):
     id = 'SnapToGrid'
-    label = '_Snap to grid'
+    label = '_Snap to Grid'
 
     def init(self, window):
         self._window = window
@@ -454,7 +456,7 @@ register_action(SnapToGridAction)
 
 class ShowGridAction(CheckAction):
     id = 'ShowGrid'
-    label = 'S_how grid'
+    label = 'S_how Grid'
 
     def init(self, window):
         self._window = window
@@ -472,3 +474,26 @@ class ShowGridAction(CheckAction):
 
 register_action(ShowGridAction)
 
+class ShowElementInTreeViewAction(Action):
+    id = 'ShowElementInTreeView'
+    label = 'S_how Element in Tree View'
+
+    def init(self, window):
+        self._window = window
+
+    def update(self):
+        diagram_tab = self._window.get_current_diagram_tab()
+        self.sensitive = diagram_tab and diagram_tab.get_view().focus_item and \
+			 diagram_tab.get_view().focus_item.item and \
+			 diagram_tab.get_view().focus_item.item.subject
+
+    def execute(self):
+        tab = self._window.get_current_diagram_tab()
+        if tab:
+            view = tab.get_view()
+	    fi = view.focus_item
+	    assert fi
+	    self._window.select_element(fi.item.subject)
+
+register_action(ShowElementInTreeViewAction)
+
