@@ -2,14 +2,16 @@
 # vim: sw=4:et
 
 import gtk
-from diagramview import DiagramView
-from abstractwindow import AbstractWindow
-import gaphor.UML
+
+from gaphor import UML
+from gaphor import resource
 from gaphor.diagram.itemtool import ItemTool
 from gaphor.diagram import get_diagram_item
 from gaphor.undomanager import get_undo_manager
+from gaphor.ui.diagramview import DiagramView
+from gaphor.ui.abstractwindow import AbstractWindow
 
-import diagramactions
+import gaphor.ui.diagramactions
 import gaphor.diagram.placementactions
 
 class DiagramTab(object):
@@ -44,7 +46,7 @@ class DiagramTab(object):
     def construct(self):
         title = self.diagram and self.diagram.name or '<None>'
 
-        table = gtk.Table(2,2, gtk.FALSE)
+        table = gtk.Table(2,2, False)
         #table.set_row_spacings (4)
         #table.set_col_spacings (4)
 
@@ -147,11 +149,14 @@ class DiagramTab(object):
         #print 'drag_data_received'
         if data and data.format == 8 and info == DiagramView.TARGET_ELEMENT_ID:
             #print 'drag_data_received:', data.data, info
-            elemfact = gaphor.resource('ElementFactory')
+            elemfact = resource(UML.ElementFactory)
             element = elemfact.lookup(data.data)
             assert element
+
+            # TODO: use adapters to execute code below
+
             item_class = get_diagram_item(type(element))
-            if isinstance(element, gaphor.UML.Diagram):
+            if isinstance(element, UML.Diagram):
                 self.owning_window.execute_action('OpenModelElement')
             elif item_class:
                 get_undo_manager().begin_transaction()
@@ -171,7 +176,7 @@ class DiagramTab(object):
 
             else:
                 log.warning ('No graphical representation for UML element %s' % type(element).__name__)
-            context.finish(gtk.TRUE, gtk.FALSE, time)
+            context.finish(True, False, time)
         else:
-            context.finish(gtk.FALSE, gtk.FALSE, time)
+            context.finish(False, False, time)
 
