@@ -6,15 +6,18 @@ Main window actions.
 import sys
 import gobject
 import gtk
-import gaphor.UML as UML
-import gaphor.diagram as diagram
-import gaphor.undomanager as undomanager
 import gc
 import traceback
 from threading import Thread
 
-import gaphor
+from gaphor import resource
+from gaphor import UML
+from gaphor import diagram
+from gaphor import undomanager
+#from gaphor.undomanager import UndoTransactionAspect, weave_method
 from gaphor.misc.action import Action, CheckAction, RadioAction, register_action
+from gaphor.misc.action import DynamicMenu, ObjectAction, register_slot
+from gaphor.misc.action import ActionError
 from gaphor.misc.gidlethread import GIdleThread, Queue, QueueEmpty
 from gaphor.misc.xmlwriter import XMLWriter
 from gaphor.misc.errorhandler import error_handler, ErrorHandlerAspect, weave_method
@@ -68,7 +71,7 @@ def show_status_window(title, message, parent=None, queue=None):
 
 class NewAction(Action):
     id = 'FileNew'
-    label = '_New'
+    label = _('_New')
     tooltip = 'Create a new Gaphor project'
     stock_id = 'gtk-new'
 
@@ -76,7 +79,7 @@ class NewAction(Action):
         self._window = window
 
     def execute(self):
-        factory = gaphor.resource(UML.ElementFactory)
+        factory = resource(UML.ElementFactory)
         if factory.size():
             dialog = gtk.MessageDialog(self._window.get_window(),
                 gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
@@ -87,7 +90,6 @@ class NewAction(Action):
             if answer != gtk.RESPONSE_YES:
                 return
 
-        factory = gaphor.resource(UML.ElementFactory)
         factory.flush()
         gc.collect()
         model = factory.create(UML.Package)
@@ -109,20 +111,26 @@ register_action(NewAction)
 
 class RevertAction(Action):
     id = 'FileRevert'
-    label = '_Revert...'
+    label = _('_Revert...')
     stock_id='gtk-revert'
     tooltip = 'Reload the loaded Gaphor project from file'
 
     def init(self, window):
+        # The filename of the last file loaded
         self.filename = None
         self._window = window
 
+    def update(self):
+        self.sensitive = bool(self._window.get_filename())
+
     def execute(self):
         filename = self._window.get_filename()
+        self.load(filename)
 
+    def load(self, filename):
         action_states = self._window.action_pool.get_action_states()
         try:
-            import gaphor.storage as storage
+            from gaphor import storage
             log.debug('Loading from: %s' % filename)
             queue = Queue()
             win = show_status_window(_('Loading...'), _('Loading model from %s') % filename, self._window.get_window(), queue)
@@ -142,6 +150,8 @@ class RevertAction(Action):
             model = self._window.get_model()
             view = self._window.get_tree_view()
 
+            self._window.set_filename(filename)
+
             # Expand all root elements:
             for node in model.root[1]:
                 view.expand_row(model.path_from_element(node[0]), False)
@@ -154,44 +164,43 @@ class RevertAction(Action):
             except:
                 pass
 
-weave_method(RevertAction.execute, ErrorHandlerAspect, message='Could not load model file.')
-register_action(RevertAction)
+weave_method(RevertAction.execute, ErrorHandlerAspect, message=_('Could not load model file.'))
+register_action(RevertAction, 'FileNew', 'FileOpen', 'FileSave', 'FileSaveAs')
 
 
 class OpenAction(RevertAction):
 
     id = 'FileOpen'
-    label = '_Open...'
+    label = _('_Open...')
     stock_id='gtk-open'
     tooltip = 'Load a Gaphor project from a file'
 
+    def update(self):
+        pass
+
     def execute(self):
-        if gtk.gtk_version < (2, 4, 0):
-            filesel = gtk.FileSelection('Open Gaphor model')
-            filesel.hide_fileop_buttons()
-        else:
-            filesel = gtk.FileChooserDialog(title='Open Gaphor model',
-                                            action=gtk.FILE_CHOOSER_ACTION_OPEN,
-                                            buttons=(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_OPEN,gtk.RESPONSE_OK))
+        filesel = gtk.FileChooserDialog(title='Open Gaphor model',
+                                        action=gtk.FILE_CHOOSER_ACTION_OPEN,
+                                        buttons=(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_OPEN,gtk.RESPONSE_OK))
 
-            filter = gtk.FileFilter()
-            filter.set_name("Gaphor models")
-            filter.add_pattern("*.gaphor")
-            filesel.add_filter(filter)
+        filter = gtk.FileFilter()
+        filter.set_name("Gaphor models")
+        filter.add_pattern("*.gaphor")
+        filesel.add_filter(filter)
 
-            filter = gtk.FileFilter()
-            filter.set_name("All files")
-            filter.add_pattern("*")
-            filesel.add_filter(filter)
+        filter = gtk.FileFilter()
+        filter.set_name("All files")
+        filter.add_pattern("*")
+        filesel.add_filter(filter)
 
-        filesel.set_filename(self.filename or '')
+        if self.filename:
+            filesel.set_current_name(self.filename)
 
         response = filesel.run()
         filename = filesel.get_filename()
         filesel.destroy()
         if filename and response == gtk.RESPONSE_OK:
-            self._window.set_filename(filename)
-            RevertAction.execute(self)
+            RevertAction.load(self, filename)
 
 register_action(OpenAction)
 
@@ -199,17 +208,18 @@ register_action(OpenAction)
 class SaveAsAction(Action):
     id = 'FileSaveAs'
     stock_id = 'gtk-save-as'
+    tooltip = _('Save the model to a new file')
 
     def init(self, window):
         self._window = window
-        self.factory = gaphor.resource('ElementFactory')
+        self.factory = resource(UML.ElementFactory)
         #self.factory.connect(self.on_element_factory)
         #self.on_element_factory(self)
         # Disconnect when the window is closed:
         #window.connect(self.on_window_closed)
 
     def on_element_factory(self, *args):
-        #factory = gaphor.resource('ElementFactory')
+        #factory = resource(UML.ElementFactory)
         if self.factory.values():
             self.sensitive = True
         else:
@@ -221,7 +231,7 @@ class SaveAsAction(Action):
 
     def save(self, filename):
         if filename and len(filename) > 0:
-            import gaphor.storage as storage
+            from gaphor import storage
             if not filename.endswith(DEFAULT_EXT):
                 filename = filename + DEFAULT_EXT
 
@@ -250,13 +260,11 @@ class SaveAsAction(Action):
 
     def execute(self):
         filename = self._window.get_filename()
-        if gtk.gtk_version < (2, 4, 0):
-            filesel = gtk.FileSelection('Save Gaphor model as')
-        else:
-            filesel = gtk.FileChooserDialog(title='Save Gaphor model as',
-                                            action=gtk.FILE_CHOOSER_ACTION_SAVE,
-                                            buttons=(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_SAVE,gtk.RESPONSE_OK))
-        filesel.set_filename(filename or '')
+        filesel = gtk.FileChooserDialog(title=_('Save Gaphor model as'),
+                                        action=gtk.FILE_CHOOSER_ACTION_SAVE,
+                                        buttons=(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_SAVE,gtk.RESPONSE_OK))
+        if filename:
+            filesel.set_current_name(filename)
         response = filesel.run()
         filename = None
         if response == gtk.RESPONSE_OK:
@@ -271,6 +279,7 @@ register_action(SaveAsAction)
 class SaveAction(SaveAsAction):
     id = 'FileSave'
     stock_id = 'gtk-save'
+    tooltip = 'Save the model to a file'
 
     def execute(self):
         filename = self._window.get_filename()
@@ -315,7 +324,7 @@ register_action(QuitAction)
 
 class OpenEditorWindowAction(Action):
     id = 'OpenEditorWindow'
-    label = '_Editor'
+    label = _('_Editor')
     tooltip = 'Open the Gaphor Editor'
 
     def init(self, window):
@@ -334,7 +343,7 @@ register_action(OpenEditorWindowAction)
 
 class OpenConsoleWindowAction(Action):
     id = 'OpenConsoleWindow'
-    label = '_Console'
+    label = _('_Console')
     tooltip = 'Open the Gaphor Console'
 
     def init(self, window):
@@ -352,7 +361,7 @@ register_action(OpenConsoleWindowAction)
 
 class ManualAction(Action):
     id = 'Manual'
-    label = '_Manual'
+    label = _('_Manual')
     stock_id = 'gtk-about'
     tooltip='Manual for Gaphor'
 
@@ -372,7 +381,7 @@ register_action(ManualAction)
 
 class AboutAction(Action):
     id = 'About'
-    label = '_About'
+    label = _('_About')
     stock_id = 'gtk-about'
     tooltip='About Gaphor'
     
@@ -380,8 +389,8 @@ class AboutAction(Action):
         self._window = window
 
     def execute(self):
-        logo = gtk.gdk.pixbuf_new_from_file (gaphor.resource('DataDir') + '/pixmaps/logo.png')
-        version = gaphor.resource('Version')
+        logo = gtk.gdk.pixbuf_new_from_file (resource('DataDir') + '/pixmaps/logo.png')
+        version = resource('Version')
         about = gtk.Dialog("About Gaphor", self._window.get_window(), gtk.DIALOG_MODAL, (gtk.STOCK_OK, gtk.RESPONSE_OK))
         about.set_default_response(gtk.RESPONSE_OK)
         vbox = about.vbox
@@ -439,7 +448,7 @@ register_action(AboutAction)
 
 class CreateDiagramAction(Action):
     id = 'CreateDiagram'
-    label = '_New diagram'
+    label = _('_New diagram')
     stock_id = 'gaphor-diagram'
 
     def init(self, window):
@@ -451,18 +460,21 @@ class CreateDiagramAction(Action):
 
     def execute(self):
         element = self._window.get_tree_view().get_selected_element()
-        diagram = gaphor.resource('ElementFactory').create(UML.Diagram)
+        diagram = resource(UML.ElementFactory).create(UML.Diagram)
         diagram.package = element
 
+        diagram.name = '%s diagram' % element.name
+
         self._window.select_element(diagram)
         self._window.execute_action('OpenModelElement')
+        self._window.execute_action('RenameModelElement')
 
 register_action(CreateDiagramAction, 'SelectRow')
 
 
 class DeleteDiagramAction(Action):
     id = 'DeleteDiagram'
-    label = '_Delete diagram'
+    label = _('_Delete diagram')
     stock_id = 'gtk-delete'
 
     def init(self, window):
@@ -491,7 +503,7 @@ register_action(DeleteDiagramAction, 'SelectRow')
 
 class OpenElementAction(Action):
     id = 'OpenModelElement'
-    label = '_Open'
+    label = _('_Open')
 
     def init(self, window):
         self._window = window
@@ -512,7 +524,7 @@ register_action(OpenElementAction, 'SelectRow')
 
 class RenameElementAction(Action):
     id = 'RenameModelElement'
-    label = '_Rename'
+    label = _('_Rename')
 
     def init(self, window):
         self._window = window
@@ -540,7 +552,7 @@ class RefreshNamespaceModelAction(Action):
     """Delete a model element through the tree view. This is only applicable
     to Diagram's and is not undoable."""
     id = 'RefreshNamespaceModel'
-    label = '_Refresh'
+    label = _('_Refresh')
 
     def init(self, window):
         self._window = window
@@ -555,7 +567,7 @@ class DeleteCommand(Action):
     """Delete a model element through the tree view. This is only applicable
     to Diagram's and is not undoable."""
     id = 'DeleteElement'
-    label = '_Delete'
+    label = _('_Delete')
 
     def set_parameters(self, params):
         self._window = params['window']
@@ -600,7 +612,7 @@ register_action(UndoStackAction)
 class UndoAction(Action):
     id = 'Undo'
     stock_id = 'gtk-undo'
-    label = '_Undo'
+    label = _('_Undo')
     tooltip = 'Undo the most recent changes'
     accel = 'C-z'
 
@@ -633,7 +645,6 @@ class RedoAction(Action):
         self.sensitive = undomanager.get_undo_manager().can_redo()
 
     def execute(self):
-        print 'RedoAction'
         undomanager.get_undo_manager().redo_transaction()
         #self.update()
         self._window.execute_action('UndoStack')
@@ -641,3 +652,49 @@ class RedoAction(Action):
 register_action(RedoAction, 'UndoStack')
 
 
+class RecentFileAction(ObjectAction):
+    """Objects created by the RecentFilesSlot are of this kind.
+    """
+
+    def init(self, window, filename):
+        self._window = window
+        self._filename = filename
+
+    def update(self):
+        pass
+
+    def execute(self):
+        revert_action = self._window.get_action_pool().get_action('FileRevert')
+        revert_action.load(self._filename)
+
+
+class RecentFilesSlot(DynamicMenu):
+    """This is the dynamic menu that contains a list of recently opened
+    model files.
+    """
+
+    def __init__(self, slot_id):
+        DynamicMenu.__init__(self, slot_id)
+
+    def get_menu(self):
+        recent_files = resource('recent-files', [])
+        window = resource('MainWindow')
+        file_list = []
+        for f, i in zip(recent_files, xrange(len(recent_files))):
+            id = 'RecentFile_%d' % i
+            try:
+                action = window.get_action_pool().get_action(id)
+                action._label='_%d. %s' % (i+1, f)
+                action._tooltip='Load %s.' % f
+            except ActionError:
+                # Create a new one if the is none registered
+                action = RecentFileAction(id,
+                                          label='_%d. %s' % (i+1, f),
+                                          tooltip='Load %s.' % f)
+                window.get_action_pool().set_action(action)
+            action.init(window, f)
+            file_list.append(id)
+        return file_list
+
+register_slot('RecentFiles', RecentFilesSlot)
+
