@@ -2,18 +2,19 @@
 # vim:sw=4:et
 
 import gtk
-import namespace
-import gaphor
-import gaphor.UML as UML
-import gaphor.undomanager as undomanager
+
+from gaphor import resource
+from gaphor import UML
+from gaphor import undomanager
 from gaphor.i18n import _
-from abstractwindow import AbstractWindow
-from diagramtab import DiagramTab
-from toolbox import Toolbox
-from menufactory import toolbox_to_menu
+from gaphor.ui import namespace
+from gaphor.ui.abstractwindow import AbstractWindow
+from gaphor.ui.diagramtab import DiagramTab
+from gaphor.ui.toolbox import Toolbox
+from gaphor.ui.menufactory import toolbox_to_menu
 
 # Load actions
-import mainactions, diagramactions
+from gaphor.ui import mainactions, diagramactions
 
 class MainWindow(AbstractWindow):
     """The main window for the application.
@@ -33,14 +34,20 @@ class MainWindow(AbstractWindow):
                 'InsertDependency',
                 'InsertGeneralization',
                 'InsertImplementation')),
+        (_('Components'), (
+                'InsertComponent',
+                'InsertNode',
+                'InsertArtifact')),
         (_('Actions'), (
                 'InsertAction',
                 'InsertInitialNode',
                 'InsertActivityFinalNode',
                 'InsertDecisionNode',
                 'InsertFlow')),
-        (_('Components'), (
-                'InsertComponent',)),
+#        (_('Interactions'), (
+#                'InsertInteraction',
+#                'InsertLifeline',
+#                'InsertMessage')),
         (_('Use Cases'), (
                 'InsertUseCase',
                 'InsertActor',
@@ -57,9 +64,9 @@ class MainWindow(AbstractWindow):
     menu = (_('_File'), (
                 'FileNew',
                 'FileOpen',
-                _('Recent files'), (
-                    _('To be implemented'),),
-                '<FileOpenSlot>',
+                'FileRevert',
+                _('Recent files'),
+                    ('<RecentFiles>',),
                 'separator',
                 'FileSave',
                 'FileSaveAs',
@@ -158,6 +165,14 @@ class MainWindow(AbstractWindow):
         """
         self.__filename = filename
 
+        # Add to recent files list
+        if filename:
+            recent_files = resource('recent-files', []) 
+            if filename not in recent_files:
+                recent_files = [filename] + recent_files[:8]
+                resource.set('recent-files', recent_files, persistent=True)
+                self.get_action_pool().get_slot('RecentFiles').rebuild()
+
     def get_filename(self):
         """Return the file name of the currently opened model.
         """
@@ -207,7 +222,7 @@ class MainWindow(AbstractWindow):
     def construct(self):
         """Create the widgets that make up the main window.
         """
-        model = namespace.NamespaceModel(gaphor.resource(UML.ElementFactory))
+        model = namespace.NamespaceModel(resource(UML.ElementFactory))
         view = namespace.NamespaceView(model)
         scrolled_window = gtk.ScrolledWindow()
         scrolled_window.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
@@ -238,20 +253,26 @@ class MainWindow(AbstractWindow):
         self.model = model
         self.view = view
 
+        window_size = resource('ui.window-size', (760, 580))
         self._construct_window(name='main',
                                title='Gaphor',
-                               size=(760, 580),
+                               size=window_size,
                                contents=paned)
 
         vbox.set_border_width(3)
 
         toolbox = Toolbox(self.menu_factory, self.toolbox)
         toolbox.construct()
+	#toolbox.connect('toggled', self.on_toolbox_toggled)
         vbox.pack_start(toolbox, expand=False)
         toolbox.show()
 
         self._toolbox = toolbox
 
+        # We want to store the window size, so it can be reloaded on startup
+        self.window.set_property('allow-shrink', True)
+        self.window.connect('size-allocate', self.on_window_size_allocate)
+
         # Set some handles for the undo manager
         undomanager.get_undo_manager().connect('begin_transaction', self.on_undo)
         undomanager.get_undo_manager().connect('add_undo_action', self.on_undo)
@@ -377,6 +398,13 @@ class MainWindow(AbstractWindow):
         """
         self.execute_action('TabChange')
 
+    def on_window_size_allocate(self, window, allocation):
+        resource.set('ui.window-size', (allocation.width, allocation.height), persistent=True)
+
+#    def on_toolbox_toggled(self, toolbox, box_name, visible):
+#        print 'Box', box_name, 'is visible:', visible
+#        #resource.set('ui.toolbox.%s' % box_name, visible, persistent=True)
+
     def on_undo(self, *args):
         self.execute_action('UndoStack')
 
@@ -390,7 +418,7 @@ class MainWindow(AbstractWindow):
 
     #def __on_element_factory_signal(self, obj, key):
         #print '__on_element_factory_signal', key
-        #factory = gaphor.resource(UML.ElementFactory)
+        #factory = resource(UML.ElementFactory)
         #self.set_capability('model', not factory.is_empty())
 
 gtk.accel_map_add_filter('gaphor')
